##  Collect Data from Integrations
SAP LeanIX offers a range of integrations that help you identify applications across your IT landscape and keep information up to date. The following integrations can support data collection as part of your modernization project:
  * [SAP Discovery](https://help.sap.com/docs/leanix/ea/sap-discovery?locale=en-US&state=PRODUCTION&version=CLOUD "Identify and manage your organization's SAP systems, services, and custom-built extensions"): Identify and manage your organization's SAP systems, services, and custom-built extensions. This gives you a complete picture of your current SAP landscape to support your transformation.
  * [ServiceNow Integration](https://help.sap.com/docs/leanix/ea/servicenow-integration?locale=en-US&state=PRODUCTION&version=CLOUD "Fundamentals of the SAP LeanIX integration with ServiceNow \(CMDB\)."): Plan service strategy and architecture in SAP LeanIX and run operations in ServiceNow. Synchronize SAP LeanIX applications with ServiceNow Business Services, and import IT components, to ensure informed modernization decisions.


YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
